@@ -1,4 +1,4 @@
-# $Id: Document.pm 42565 2014-11-17 14:06:46Z wsl $
+# $Id: Document.pm 47800 2018-09-27 12:12:37Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Document.pm $
 
 use strict;
@@ -92,9 +92,6 @@ sub response {
 	# Don't try to second guess the content type
 	$res->setheader('X-Content-Type-Options' => 'nosniff');
 
-	# Protect against clickjacking
-	$res->setheader('X-Frame-Options' => 'DENY');
-
 	$res->mimetype('application/xml')
 		if $req->raw;
 
